Index: trunk/ppImage/src/ppImageOptions.c
===================================================================
--- trunk/ppImage/src/ppImageOptions.c	(revision 20626)
+++ trunk/ppImage/src/ppImageOptions.c	(revision 21364)
@@ -19,5 +19,5 @@
     // actions which ppImage should perform
     options->doMaskBuild     = false;   // Build internal mask
-    options->doWeightBuild   = false;   // Build internal weight
+    options->doVarianceBuild   = false;   // Build internal variance
     options->doMask          = false;   // Mask bad pixels
     options->doNonLin        = false;   // Non-linearity correction
@@ -37,9 +37,9 @@
     options->BaseFITS        = false;   // create output image
     options->BaseMaskFITS    = false;   // create output mask image
-    options->BaseWeightFITS  = false;   // create output weight image
+    options->BaseVarianceFITS  = false;   // create output variance image
 
     options->ChipFITS        = false;   // create output chip-mosaic image
     options->ChipMaskFITS    = false;   // create output chip-mosaic mask image
-    options->ChipWeightFITS  = false;   // create output chip-mosaic weight image
+    options->ChipVarianceFITS  = false;   // create output chip-mosaic variance image
 
     options->FPA1FITS        = false;   // create fpa-mosaic binned image (scale 1)
@@ -194,5 +194,5 @@
     // for these images, even if not required otherwise
     options->doMaskBuild = psMetadataLookupBool(NULL, recipe, "MASK.BUILD");
-    options->doWeightBuild = psMetadataLookupBool(NULL, recipe, "WEIGHT.BUILD");
+    options->doVarianceBuild = psMetadataLookupBool(NULL, recipe, "VARIANCE.BUILD");
 
     // Mask recipe options (note that mask bit values are set in ppImageSetMaskBits.c)
@@ -236,9 +236,9 @@
     options->BaseFITS       = psMetadataLookupBool(NULL, recipe, "BASE.FITS");
     options->BaseMaskFITS   = psMetadataLookupBool(NULL, recipe, "BASE.MASK.FITS");
-    options->BaseWeightFITS = psMetadataLookupBool(NULL, recipe, "BASE.WEIGHT.FITS");
+    options->BaseVarianceFITS = psMetadataLookupBool(NULL, recipe, "BASE.VARIANCE.FITS");
 
     options->ChipFITS       = psMetadataLookupBool(NULL, recipe, "CHIP.FITS");
     options->ChipMaskFITS   = psMetadataLookupBool(NULL, recipe, "CHIP.MASK.FITS");
-    options->ChipWeightFITS = psMetadataLookupBool(NULL, recipe, "CHIP.WEIGHT.FITS");
+    options->ChipVarianceFITS = psMetadataLookupBool(NULL, recipe, "CHIP.VARIANCE.FITS");
 
     options->FPA1FITS       = psMetadataLookupBool(NULL, recipe, "FPA1.FITS");
@@ -255,9 +255,9 @@
     options->doBG           = psMetadataLookupBool(NULL, recipe, "BACKGROUND");
 
     // even if not requested explicitly, if any of these are set, build an internal mask and weight:
     if (options->doBias || options->doOverscan || options->doDark || options->doShutter || options->doFlat ||
         options->doPhotom) {
         options->doMaskBuild = true;
-        options->doWeightBuild = true;
+        options->doVarianceBuild = true;
     } else if (options->doMask || options->doBG) {
         options->doMaskBuild = true;
@@ -255,9 +255,9 @@
     options->doBG           = psMetadataLookupBool(NULL, recipe, "BACKGROUND");
 
-    // even if not requested explicitly, if any of these are set, build an internal mask and weight:
+    // even if not requested explicitly, if any of these are set, build an internal mask and variance:
     if (options->doBias || options->doOverscan || options->doDark || options->doShutter || options->doFlat ||
         options->doPhotom) {
